@@ -17,8 +17,9 @@ use File::chdir;
 use Group::Git::Repo;
 use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
+use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.5.0');
+our $VERSION = version->new('0.5.2');
 our $AUTOLOAD;
 
 has conf => (
@@ -55,20 +56,16 @@ has paging => (
 );
 
 # load all roles in the namespace Group::Git::Cmd::*
-my %modules;
-for my $dir (@INC) {
-    next if !-d "$dir/Group/Git/Cmd";
-    local $CWD = $dir;
-    my @commands = glob "Group/Git/Cmd/*.pm";
-
-    for my $command (@commands) {
-        my $module = $command;
-        $module =~ s{/}{::}g;
-        $module =~ s{[.]pm$}{};
-        if ( !$modules{$module}++ ) {
-            require $command;
-            with $module;
-        }
+my @plugins = Group::Git->plugins;
+our $taggers = {};
+for my $plugin (@plugins) {
+    if ($plugin =~ /Group::Git::Cmd::/) {
+        with $plugin;
+    }
+    else {
+        my $tag = $plugin;
+        $tag =~ s/^.*:://;
+        $taggers->{lc $tag} = $plugin;
     }
 }
 
@@ -147,7 +144,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.5.0.
+This documentation refers to Group::Git version 0.5.2.
 
 =head1 SYNOPSIS
 
