@@ -15,25 +15,49 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.5.0');
+our $VERSION = version->new('0.5.2');
 
 requires 'repos';
 requires 'verbose';
 
+has repo_count => (
+    is      => 'rw',
+    default => 0,
+);
+
 my $opt = Getopt::Alt->new(
     { help => __PACKAGE__, },
     [
         'quiet|q',
+        'verbose|v',
     ]
 );
 
+sub list_start {
+    $opt->process;
+
+    return;
+}
+
 sub list {
     my ($self, $name) = @_;
     return unless -d $name;
 
+    $self->repo_count($self->repo_count + 1);
+
     return ' ';
 }
 
+sub list_end {
+    my ($self) = @_;
+
+    if ($opt->opt->verbose) {
+        return "\nSummary:\nFound " . $self->repo_count . " repositories\n";
+    }
+
+    return;
+}
+
 1;
 
 __END__
@@ -44,7 +68,7 @@ Group::Git::Cmd::List - Runs git status on a git project
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::List version 0.5.0.
+This documentation refers to Group::Git::Cmd::List version 0.5.2.
 
 
 =head1 SYNOPSIS
@@ -66,6 +90,18 @@ This documentation refers to Group::Git::Cmd::List version 0.5.0.
 
 Just prints C<$name> to STDERR if such a directory exists.
 
+=item C<list_start ()>
+
+Processes command line options
+
+=item C<list_end ()>
+
+If summary is asked for this returns the count of repositories found
+
+=item C<repo_count ([$count])>
+
+Gets/sets the count of repositories found.
+
 =back
 
 =head1 DIAGNOSTICS
