@@ -17,7 +17,7 @@ use JSON qw/decode_json/;
 use WWW::Mechanize;
 use Path::Class;
 
-our $VERSION = version->new('0.5.0');
+our $VERSION = version->new('0.5.2');
 
 extends 'Group::Git';
 
@@ -49,7 +49,7 @@ sub _repos {
     @ARGV = @argv;
 
     while ($more) {
-        $mech->get( $url . $start++ );
+        $mech->get( $url . $start );
         my $response = decode_json $mech->content;
 
         for my $repo (@{ $response->{values} }) {
@@ -65,7 +65,8 @@ sub _repos {
             );
             push @{ $conf->{tags}{$project} }, "$dir";
         }
-        $more = !$response->{isLastPage};
+        $more  = !$response->{isLastPage};
+        $start = $response->{nextPageStart};
     }
 
     return \%repos;
@@ -81,7 +82,7 @@ Group::Git::Stash - Adds reading all repositories you have access to on your loc
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Stash version 0.5.0.
+This documentation refers to Group::Git::Stash version 0.5.2.
 
 =head1 SYNOPSIS
 
